@@ -70,6 +70,10 @@ add module template file for new module L<Module::Setup::Plugin::VC::Git>
 
 for template process L<Module::Setup::Plugin::Template>
 
+=head2 replace_distribute_path $options
+
+for distribute path rewrite phase
+
 =head2 check_skeleton_directory
 
   for test L<Module::Setup::Plugin::Test::Makefile>
